#
# spec file for package phonon4qt5-backend-vlc
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define filename phonon-backend-vlc
%define _phonon4qt5_version 4.10.60
%bcond_without lang
Name:           phonon4qt5-backend-vlc
Version:        0.11.3
Release:        1.12
Summary:        Phonon VLC Backend
License:        LGPL-2.1-or-later
Group:          Development/Libraries/KDE
URL:            https://phonon.kde.org/
Source:         https://download.kde.org/stable/phonon/%{filename}/%{version}/%{filename}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  kf5-filesystem
BuildRequires:  vlc-devel >= 2.1.0
BuildRequires:  cmake(Phonon4Qt5) >= %{_phonon4qt5_version}
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Widgets)
Requires:       libphonon4qt5 >= %{_phonon4qt5_version}
Requires:       vlc-noX >= %( echo `rpm -q --queryformat '%%{VERSION}' vlc-devel`)
Conflicts:      vlc-noX > %( echo `rpm -q --queryformat '%%{VERSION}' vlc-devel | cut -f -2 -d .`.99)
Provides:       phonon4qt5-backend = %{version}

%description
Phonon is a cross-platform portable Multimedia Support Abstraction,
which allows you to play multiple audio or video formats with the same
quality on all platforms, no matter which underlying architecture is
used.

This is the VLC backend for Phonon

%lang_package

%prep
%setup -q -n phonon-backend-vlc-%{version}

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%if %{with lang}
  %find_lang phonon_vlc %{name}.lang --with-qt
%endif

%post
%if 0%{?suse_version} >= 1500
%{_libdir}/vlc/vlc-cache-gen %{_libdir}/vlc/plugins
%else
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins
%endif

%files
%license COPYING.LIB
%doc AUTHORS
%dir %{_kf5_plugindir}/phonon4qt5_backend
%{_kf5_plugindir}/phonon4qt5_backend/phonon_vlc.so

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Thu Apr  1 2021 wbauer@tmo.at
- Update to 0.11.3
  * Further extended the PulseSupport shutdown introduced in 0.11.2
    to now also apply when MediaObject reset. This additionally
    ought to prevent crashes inside libpulse when playing multiple
    files on the same MediaObject.
  * Fixed a wayland crash when using surface painting (e.g. used in
    Dolphin sidebar previews).
  * Frame pitch and line calculation for surface painting has been
    made much cheaper.
  * The memory footprint of surface painting has been cut in half.
* Tue Feb 16 2021 wbauer@tmo.at
- Update to 0.11.2
  * Assert that the internal player object doesn't freakishly fail
    to allocate.
  * Fully shutdown Phonon's PulseSupport upon destruction of
    MediaObjects to prevent a randomly occurring shutdown race
    resulting in a crash somewhere between the threaded pulseaudio
    mainloop inside libvlc and the glib mainloop inside Phonon.
    This was a somewhat common crash on application quit usually
    presenting as a failed assert inside pulsecore/fdsem.c.
* Thu Sep 26 2019 wbauer@tmo.at
- Update to 0.11.1
  * Video playback in wayland sessions no longer causes a separate
    window to pop up (kde#405114)
* Fri Aug 30 2019 wbauer@tmo.at
- Update to 0.11.0:
  * This version of Phonon VLC is compatible with Phonon 4.11+ and
    its revised build systems. Older versions of Phonon VLC no
    longer build against newer Phonon releases. Conversely this
    version no longer builds with older Phonon releases.
  * Qt4 support has been removed. Qt5 is now the default.
* Fri Jul 19 2019 wbauer@tmo.at
- Update to 0.10.3:
  * Localization has been fixed for the Qt 5 build.
- Add lang subpackage containing the translations
* Thu Jan 10 2019 wbauer@tmo.at
- Update to 0.10.2:
  * libvlc's internal screensaver inhibitor is now explicitly
    disabled. Applications are expected to inhibit manually (from
    an API they always were; now this is actually correctly
    abstracted from libvlc's defaults). The built-in libvlc
    inhibition is not consistent with other backends' behavior and
    can in fact cause dbus time outs when attempting to uninhibit
    on player shutdown (e.g. applications getting stuck for 30
    seconds on quit).
  * CMake output for libvlc has been made more verbose to aid
    diagnostics when libvlc is not found, or not completely found
    anyway. Previously the verbose output was only generated on
    success scenarios, where it is distinctly less useful, now it
    is also generated when libvlc was not found.
- Run spec-cleaner
* Tue Feb 27 2018 wbauer@tmo.at
- Update to 0.10.1:
  * Fix build with VLC < 3.0
- Drop fix-build-with-vlc2.patch, merged upstream
* Fri Feb 23 2018 wbauer@tmo.at
- Update to 0.10.0:
  * Changes
    + Mimetype support list has been synced with latest VLC
  * Bug Fixes
    + The health of our users is very dear to us, so we've lowered
    the default volume to 75%% to not blow their ears out in the
    event of failure or badly configured frontend software
    + Volume application has been revised and now applies less
    aggressively. This gives PulseAudio a change to apply/restore
    its own default volume.
    + Volume application and correct role forwarding into VLC
    finally make the PulseAudio notification volume apply
    properly to notifications issued via Phonon (VLC 3 only).
  * VLC 3.0 API Pickup
    + New player role is being used to set the output category on a
    PulseAudio level. This fixes a long-standing bug where VLC
    based audio would always be categorized as video.
    + Various deprecation porting.
- Add fix-build-with-vlc2.patch to make it compile with VLC 2.x
* Sun Feb 18 2018 wbauer@tmo.at
- Update to 0.9.1
  * Fix building against older Phonon versions
  * Prevent compilation errors by avoiding preprocessor macros that
    could conflict with VLC's own names (kde#364582)
  * Removed excess warnings from the OS X video widget
  * Introduced a workaround for a double-release bug in the OS X
    video widget introduced in Qt 5.8.0.
- Call vlc-cache-gen without -f option in %%post on Tumbleweed,
  that option apparently doesn't exist anymore in vlc 3.0
- Drop fix-build-with-older-phonon.patch, merged upstream
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Fri May 13 2016 wbauer@tmo.at
- Require VLC 2.1.0 at least for building, support for 2.0.x has
  been removed upstream
* Mon May  9 2016 wbauer@tmo.at
- Added fix-build-with-older-phonon.patch to fix building against
  older phonon versions
- Also change required phonon4qt5 version back to 4.7.0, it doesn't
  need a higher one to build successfully
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 0.9.0
  * No changelog provided
* Mon Apr  4 2016 wbauer@tmo.at
- Conflict with newer VLC versions to prevent problems or even
  crashes (boo#968905)
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 0.8.2:
  * Fix compilation with Qt 5.2.0
* Wed Nov  5 2014 hrvoje.senjan@gmail.com
- Update to 0.8.1:
  * Code style improvements.
  * VLC 2.2 compatibility - VLC 2.2 changed the time when
    PulseAudio streams are constructed, rendering the Phonon
    PulseSupport non-functional as it injects stream-dependent
    properties through the environment which needs to happen close
    to stream creation to avoid timing issues. The changed stream
    creation time makes it impossible to provide high-level
    PulseAudio control while also allowing Phonon applications to
    construct multiple AudioOutputs in a very short time frame.
    To allow core functionality from working under these
    circumstances Phonon PulseSupport integration is disabled
    when built against VLC >= 2.2 leading to the following
    known regressions:
    Changing the volume through the PulseAudio stream itself
    is not propagated to Phonon AudioOutputs, meaning the
    application can not reflect volume changes done through
    other applications (e.g. a volume mixer).
    Changing the muteness through the PulseAudio stream is
    not propagated either.
    The PulseAudio media.role property (as well as derived
    properties) is always set to 'video' making all Phonon
    application use the video category for output device
    selection (e.g. as seen in the Phonon KCM).
  * Revised the logic used to come up with an icon name for
    libvlc. If the application has QApplication::windowIcon
    set with an QIcon constructed through QIcon::fromTheme(string)
    the actual icon name will be used.
    Otherwise the lower-case version of
    QCoreApplication::applicationName is used.
  * Setting the libvlc app id is now only dependent on
    QCoreApplication::applicationName being set (previously
    it was also dependent on QCoreApplication::applicationVersion).
    This change was made to accomodate the fact that most
    applications neglect to set a version.
- Bump phonon4qt5 (Build)Requires to 4.8.2
* Sun Oct 19 2014 hrvoje.senjan@gmail.com
- Update to 0.8.0
  * Version bump
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Update to 0.7.80
  * 0.8 beta: PA interaction improvements, documentation fixes and
    standard bugfixes
- Bump phonon (Build)Requires to 4.7.80
* Tue Jul  8 2014 hrvoje.senjan@gmail.com
- Refresh vlc plugin in %%post (https://trac.videolan.org/vlc/ticket/9807)
* Fri Jun 20 2014 hrvoje.senjan@gmail.com
- Update to 0.7.2
  * Bugfix release, no changelog provided
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Adjust filelists to kf5-filesystem changes
* Mon Feb 24 2014 hrvoje.senjan@gmail.com
- Added pkgconfig(Qt5Core), pkgconfig(Qt5Gui) and pkgconfig(Qt5Widgets)
  BuildRequires instead of relying on phonon4qt5-devel Requires
* Wed Feb 19 2014 hrvoje.senjan@gmail.com
- Activate phonon4qt5-backend-vlc package (built against/for
  phonon4qt5). Changes based on phonon-backend-vlc for
  preserving history
- Move to kf5-filesystem, instead of kde4 one
* Fri Dec  6 2013 hrvoje.senjan@gmail.com
- Update to 0.7.1:
  * Bugfix release, no changelog provided
- Bump required phonon version to 4.7.1
- Fix Source URL
* Tue Nov 19 2013 hrvoje.senjan@gmail.com
- Relax vlc-noX requirement, for making it easier to install VLC from
  alternative repositories (bnc#851063)
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to official 0.7.0 release
  * No source changes since last update
- Add Source URL
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to 0.7.0~git20131104
  * Buildsystem fixes since previous snapshot
  * Version bump to 0.7.0
* Sun Oct  6 2013 hrvoje.senjan@gmail.com
- Make phonon-backend-vlc require exact vlc-noX package version
  as vlc version it was compiled against
* Mon Sep 30 2013 hrvoje.senjan@gmail.com
- Update to 0.6.80~git20130930
  * do not release and allocate media_t on audiocd track change
  * do not reset autoplay as applications can set that any time
  * implement attemptautoplay mechanic
* Mon Sep 16 2013 hrvoje.senjan@gmail.com
- Explicitly require current libphonon4 version (4.6.80~git20130915)
* Sun Sep 15 2013 hrvoje.senjan@gmail.com
- Update to 0.6.80~git20130915
  * Snapshot of soon to be released 0.7 version
  * Various improvements, bugfixes, API aditions, documentation fixes
  * Qt5 support
  * Support for vlc's equalizer, when built with vlc >= 2.2
* Sun Apr  7 2013 tittiatcoke@gmail.com
- Initial package for the Phonon VLC backend (0.6.2)
